==> multiple_select-8.x-1.3.tar.gz: multiple_select/src/Form/BulkConfigForm.php <==
<?php

namespace Drupal\multiple_select\Form;

use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * BulkConfigForm form.
 */
class BulkConfigForm extends FormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'multiple_select_admin_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {

    $data = \Drupal::state()->get('multiple_select_config');
    if (!is_null($data)) {
      $shared_bulk_config = json_decode($data, TRUE);
    }
    $options = [
      'node' => [
        'readable' => 'Node',
        'type' => 'node_type',
      ],
      'media' => [
        'readable' => 'Media',
        'type' => 'media_type',
      ],
    ];

    foreach ($options as $type => $entity) {
      $entity_types = $this->getTypes($entity['type']);
      if (count($entity_types) > 0) {

        $form[$type] = [
          '#type' => 'label',
          '#title' => $entity['readable'],
          '#prefix' => '<br/>',
        ];
      }

      foreach ($entity_types as $entity_type) {
        $entity_fields = [];
        $bundle_fields = \Drupal::entityManager()->getFieldDefinitions($type, $entity_type->id());
        foreach ($bundle_fields as $field) {
          if ($field->getType() == 'list_string' || $field->getType() == 'entity_reference') {
            $entity_fields[$field->getName()] = $field->getLabel();
          }
        }

        $default = !is_null($data) && isset($shared_bulk_config[$entity_type->id()]) ? 1 : 0;
        $form[$entity_type->id()] = [
          '#type' => 'checkbox',
          '#title' => $entity_type->label(),
          '#default_value' => $default,
        ];

        if (empty($entity_fields)) {
          $form[$entity_type->id()]['#disabled'] = TRUE;
        }
        else {
          $default_fields = !is_null($data) && isset($shared_bulk_config[$entity_type->id()]) ? $shared_bulk_config[$entity_type->id()] : NULL;
          $form[$entity_type->id() . '_' . $type] = [
            '#type' => 'select',
            '#multiple' => TRUE,
            '#default_value' => $default_fields,
            '#options' => $entity_fields,
            '#states' => [
              'visible' => [
                ':input[name="' . $entity_type->id() . '"]' => ['checked' => TRUE],
              ],
            ],
          ];
        }

      }
    }
    $form['text'] = [
      '#markup' => $this->t('NOTE: only field of type "Check boxes" will be affected.'),
    ];

    $form['submit'] = [
      '#type' => 'submit',
      '#value' => $this->t('Submit'),
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    \Drupal::state()->set('multiple_select_config', NULL);
    $options = [
      'node' => [
        'readable' => 'Node',
        'type' => 'node_type',
      ],
      'media' => [
        'readable' => 'Media',
        'type' => 'media_type',
      ],
    ];
    foreach ($options as $type => $entity) {
      foreach ($this->getTypes($entity['type']) as $entity_type) {
        if ($form_state->getValue($entity_type->id()) != 0) {
          $shared_bulk_config[$entity_type->id()] = $form_state->getValue($entity_type->id() . '_' . $type);
        }
      }
    }
    \Drupal::state()->set('multiple_select_config', json_encode($shared_bulk_config));
    drupal_set_message($this->t('Configurations successfully saved.'));
  }

  /**
   * Get existing entity types.
   */
  public function getTypes($type) {
    $entityTypeManager = \Drupal::entityTypeManager();
    $types = [];
    if (\Drupal::entityTypeManager()->hasDefinition($type)) {
      foreach ($entityTypeManager->getStorage($type)->loadMultiple() as $instance) {
        $types[] = $instance;
      }
    }
    return $types;
  }

}

==> multiple_select-8.x-1.4.tar.gz: multiple_select/src/Form/BulkConfigForm.php <==
<?php

namespace Drupal\multiple_select\Form;

use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * BulkConfigForm form.
 */
class BulkConfigForm extends FormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'multiple_select_admin_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {

    $data = \Drupal::state()->get('multiple_select_config');
    if (!is_null($data)) {
      $shared_bulk_config = json_decode($data, TRUE);
    }
    $options = [
      'node' => [
        'readable' => 'Node',
        'type' => 'node_type',
      ],
      'media' => [
        'readable' => 'Media',
        'type' => 'media_type',
      ],
    ];

    foreach ($options as $type => $entity) {
      $entity_types = $this->getTypes($entity['type']);
      if (count($entity_types) > 0) {

        $form[$type] = [
          '#type' => 'label',
          '#title' => $entity['readable'],
          '#prefix' => '<br/>',
        ];
      }

      foreach ($entity_types as $entity_type) {
        $entity_fields = [];
        $bundle_fields = \Drupal::service('entity_field.manager')->getFieldDefinitions($type, $entity_type->id());
        foreach ($bundle_fields as $field) {
          if ($field->getType() == 'list_string' || $field->getType() == 'entity_reference') {
            $entity_fields[$field->getName()] = $field->getLabel();
          }
        }

        $default = !is_null($data) && isset($shared_bulk_config[$entity_type->id()]) ? 1 : 0;
        $form[$entity_type->id()] = [
          '#type' => 'checkbox',
          '#title' => $entity_type->label(),
          '#default_value' => $default,
        ];

        if (empty($entity_fields)) {
          $form[$entity_type->id()]['#disabled'] = TRUE;
        }
        else {
          $default_fields = !is_null($data) && isset($shared_bulk_config[$entity_type->id()]) ? $shared_bulk_config[$entity_type->id()] : NULL;
          $form[$entity_type->id() . '_' . $type] = [
            '#type' => 'select',
            '#multiple' => TRUE,
            '#default_value' => $default_fields,
            '#options' => $entity_fields,
            '#states' => [
              'visible' => [
                ':input[name="' . $entity_type->id() . '"]' => ['checked' => TRUE],
              ],
            ],
          ];
        }

      }
    }
    $form['text'] = [
      '#markup' => $this->t('NOTE: only field of type "Check boxes" will be affected.'),
    ];

    $form['submit'] = [
      '#type' => 'submit',
      '#value' => $this->t('Submit'),
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    \Drupal::state()->set('multiple_select_config', NULL);
    $options = [
      'node' => [
        'readable' => 'Node',
        'type' => 'node_type',
      ],
      'media' => [
        'readable' => 'Media',
        'type' => 'media_type',
      ],
    ];
    foreach ($options as $type => $entity) {
      foreach ($this->getTypes($entity['type']) as $entity_type) {
        if ($form_state->getValue($entity_type->id()) != 0) {
          $shared_bulk_config[$entity_type->id()] = $form_state->getValue($entity_type->id() . '_' . $type);
        }
      }
    }
    \Drupal::state()->set('multiple_select_config', json_encode($shared_bulk_config));
     $this->messenger()->addStatus($this->t('Configurations successfully saved.'));
  }

  /**
   * Get existing entity types.
   */
  public function getTypes($type) {
    $entityTypeManager = \Drupal::entityTypeManager();
    $types = [];
    if (\Drupal::entityTypeManager()->hasDefinition($type)) {
      foreach ($entityTypeManager->getStorage($type)->loadMultiple() as $instance) {
        $types[] = $instance;
      }
    }
    return $types;
  }

}
